@@ -34,12 +34,6 @@ ContainmentPrivate::ContainmentPrivate(Containment *c)
     , uiReady(false)
     , appletsUiReady(false)
 {
-    // if the parent is an applet (i.e we are the systray)
-    // we want to follow screen changed signals from the parent's containment
-    auto appletParent = qobject_cast<Plasma::Applet *>(c->parent());
-    if (appletParent) {
-        QObject::connect(appletParent->containment(), &Containment::screenChanged, c, &Containment::screenChanged);
-    }
     activityInfo = new KActivities::Info(activityId, q);
     QObject::connect(activityInfo, &KActivities::Info::nameChanged, q, &Containment::activityNameChanged);
 }
@@ -53,7 +47,6 @@ void ContainmentPrivate::addDefaultActions(QMap<QString, QAction *> &actions, Co
 {
     // adjust applet actions
     QAction *appAction = actions.value(QStringLiteral("remove"));
-    appAction->setShortcut(QKeySequence(Qt::ALT | Qt::Key_D, Qt::ALT | Qt::Key_R));
     if (c && c->d->isPanelContainment()) {
         appAction->setText(i18n("Remove this Panel"));
     } else {
@@ -62,7 +55,6 @@ void ContainmentPrivate::addDefaultActions(QMap<QString, QAction *> &actions, Co
 
     appAction = actions.value(QStringLiteral("configure"));
     if (appAction) {
-        appAction->setShortcut(QKeySequence(Qt::ALT | Qt::Key_D, Qt::ALT | Qt::Key_S));
         appAction->setText(i18n("Activity Settings"));
     }
 
@@ -77,7 +69,6 @@ void ContainmentPrivate::addDefaultActions(QMap<QString, QAction *> &actions, Co
     appletBrowserAction->setAutoRepeat(false);
     appletBrowserAction->setText(i18n("Add or Manage Widgets…"));
     appletBrowserAction->setIcon(QIcon::fromTheme(QStringLiteral("view-group-symbolic")));
-    appletBrowserAction->setShortcut(QKeySequence(Qt::ALT | Qt::Key_D, Qt::Key_A));
 
     if (c) {
         static_cast<Plasma::Applet *>(c)->d->actions.insert(actions);
